import type { EventResponse } from '../models/EventResponse';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class EventsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get events on a resource
     * Returns the full record for all events that have occurred since the sync
     * token was created.
     *
     * A `GET` request to the endpoint `/[path_to_resource]/events` can be made in
     * lieu of including the resource ID in the data for the request.
     *
     * Asana limits a single sync token to 100 events. If more than 100 events exist
     * for a given resource, `has_more: true` will be returned in the response, indicating
     * that there are more events to pull.
     *
     * *Note: The resource returned will be the resource that triggered the
     * event. This may be different from the one that the events were requested
     * for. For example, a subscription to a project will contain events for
     * tasks contained within the project.*
     * @returns any Successfully retrieved events.
     * @throws ApiError
     */
    getEvents({ resource, sync, optPretty, optFields, }: {
        /**
         * A resource ID to subscribe to. The resource can be a task or project.
         */
        resource: string;
        /**
         * A sync token received from the last request, or none on first sync. Events will be returned from the point in time that the sync token was generated.
         * *Note: On your first request, omit the sync token. The response will be the same as for an expired sync token, and will include a new valid sync token.If the sync token is too old (which may happen from time to time) the API will return a `412 Precondition Failed` error, and include a fresh sync token in the response.*
         */
        sync?: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: Array<EventResponse>;
        /**
         * A sync token to be used with the next call to the /events endpoint.
         */
        sync?: string;
        /**
         * Indicates whether there are more events to pull.
         */
        has_more?: boolean;
    }>;
}
