import type { JobCompact } from '../models/JobCompact';
import type { ProjectTemplateCompact } from '../models/ProjectTemplateCompact';
import type { ProjectTemplateInstantiateProjectRequest } from '../models/ProjectTemplateInstantiateProjectRequest';
import type { ProjectTemplateResponse } from '../models/ProjectTemplateResponse';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class ProjectTemplatesService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get a project template
     * Returns the complete project template record for a single project template.
     * @returns any Successfully retrieved the requested project template.
     * @throws ApiError
     */
    getProjectTemplate({ projectTemplateGid, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the project template.
         */
        projectTemplateGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: ProjectTemplateResponse;
    }>;
    /**
     * Get multiple project templates
     * Returns the compact project template records for all project templates in the given team or workspace.
     * @returns any Successfully retrieved the requested team's or workspace's project templates.
     * @throws ApiError
     */
    getProjectTemplates({ optPretty, optFields, workspace, team, limit, offset, }: {
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * The workspace to filter results on.
         */
        workspace?: string;
        /**
         * The team to filter projects on.
         */
        team?: string;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<ProjectTemplateCompact>;
    }>;
    /**
     * Get a team's project templates
     * Returns the compact project template records for all project templates in the team.
     * @returns any Successfully retrieved the requested team's project templates.
     * @throws ApiError
     */
    getProjectTemplatesForTeam({ teamGid, optPretty, optFields, limit, offset, }: {
        /**
         * Globally unique identifier for the team.
         */
        teamGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<ProjectTemplateCompact>;
    }>;
    /**
     * Instantiate a project from a project template
     * Creates and returns a job that will asynchronously handle the project instantiation.
     *
     * To form this request, it is recommended to first make a request to [get a project template](/docs/get-a-project-template). Then, from the response, copy the `gid` from the object in the `requested_dates` array. This `gid` should be used in `requested_dates` to instantiate a project.
     *
     * _Note: The body of this request will differ if your workspace is an organization. To determine if your workspace is an organization, use the [is_organization](/docs/workspace) parameter._
     * @returns any Successfully created the job to handle project instantiation.
     * @throws ApiError
     */
    instantiateProject({ projectTemplateGid, optPretty, optFields, requestBody, }: {
        /**
         * Globally unique identifier for the project template.
         */
        projectTemplateGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Describes the inputs used for instantiating a project, such as the resulting project's name, which team it should be created in, and values for date variables.
         */
        requestBody?: {
            data?: ProjectTemplateInstantiateProjectRequest;
        };
    }): CancelablePromise<{
        data?: JobCompact;
    }>;
}
