import type { EmptyResponse } from '../models/EmptyResponse';
import type { ProjectSectionInsertRequest } from '../models/ProjectSectionInsertRequest';
import type { SectionCompact } from '../models/SectionCompact';
import type { SectionRequest } from '../models/SectionRequest';
import type { SectionResponse } from '../models/SectionResponse';
import type { SectionTaskInsertRequest } from '../models/SectionTaskInsertRequest';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class SectionsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get a section
     * Returns the complete record for a single section.
     * @returns any Successfully retrieved section.
     * @throws ApiError
     */
    getSection({ sectionGid, optPretty, optFields, }: {
        /**
         * The globally unique identifier for the section.
         */
        sectionGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: SectionResponse;
    }>;
    /**
     * Update a section
     * A specific, existing section can be updated by making a PUT request on
     * the URL for that project. Only the fields provided in the `data` block
     * will be updated; any unspecified fields will remain unchanged. (note that
     * at this time, the only field that can be updated is the `name` field.)
     *
     * When using this method, it is best to specify only those fields you wish
     * to change, or else you may overwrite changes made by another user since
     * you last retrieved the task.
     *
     * Returns the complete updated section record.
     * @returns any Successfully updated the specified section.
     * @throws ApiError
     */
    updateSection({ sectionGid, requestBody, optPretty, optFields, }: {
        /**
         * The globally unique identifier for the section.
         */
        sectionGid: string;
        /**
         * The section to create.
         */
        requestBody: {
            data?: SectionRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: SectionResponse;
    }>;
    /**
     * Delete a section
     * A specific, existing section can be deleted by making a DELETE request on
     * the URL for that section.
     *
     * Note that sections must be empty to be deleted.
     *
     * The last remaining section cannot be deleted.
     *
     * Returns an empty data block.
     * @returns any Successfully deleted the specified section.
     * @throws ApiError
     */
    deleteSection({ sectionGid, optPretty, optFields, }: {
        /**
         * The globally unique identifier for the section.
         */
        sectionGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: EmptyResponse;
    }>;
    /**
     * Get sections in a project
     * Returns the compact records for all sections in the specified project.
     * @returns any Successfully retrieved sections in project.
     * @throws ApiError
     */
    getSectionsForProject({ projectGid, optPretty, optFields, limit, offset, }: {
        /**
         * Globally unique identifier for the project.
         */
        projectGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<SectionCompact>;
    }>;
    /**
     * Create a section in a project
     * Creates a new section in a project.
     * Returns the full record of the newly created section.
     * @returns any Successfully created the specified section.
     * @throws ApiError
     */
    createSectionForProject({ projectGid, requestBody, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the project.
         */
        projectGid: string;
        /**
         * The section to create.
         */
        requestBody: {
            data?: SectionRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: SectionResponse;
    }>;
    /**
     * Add task to section
     * Add a task to a specific, existing section. This will remove the task from other sections of the project.
     *
     * The task will be inserted at the top of a section unless an insert_before or insert_after parameter is declared.
     *
     * This does not work for separators (tasks with the resource_subtype of section).
     * @returns any Successfully added the task.
     * @throws ApiError
     */
    addTaskForSection({ sectionGid, requestBody, optPretty, optFields, }: {
        /**
         * The globally unique identifier for the section.
         */
        sectionGid: string;
        /**
         * The task and optionally the insert location.
         */
        requestBody: {
            data?: SectionTaskInsertRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: EmptyResponse;
    }>;
    /**
     * Move or Insert sections
     * Move sections relative to each other. One of
     * `before_section` or `after_section` is required.
     *
     * Sections cannot be moved between projects.
     *
     * Returns an empty data block.
     * @returns any Successfully moved the specified section.
     * @throws ApiError
     */
    insertSectionForProject({ projectGid, requestBody, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the project.
         */
        projectGid: string;
        /**
         * The section's move action.
         */
        requestBody: {
            data?: ProjectSectionInsertRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: EmptyResponse;
    }>;
}
